==> webkit2gtk_2.20.1.orig.tar.xz: webkitgtk-2.20.1/Source/JavaScriptCore/bytecode/SpecialPointer.h <==
/*
 * Copyright (C) 2012 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

namespace JSC {

class CodeBlock;
class JSGlobalObject;

namespace Special {
enum Pointer {
    CallFunction,
    ApplyFunction,
    ObjectConstructor,
    ArrayConstructor,
    TableSize // Not a real special pointer. Use this to determine the number of pointers.
};
} // namespace Special

enum class LinkTimeConstant {
    ThrowTypeErrorFunction,
};
const unsigned LinkTimeConstantCount = 1;

inline bool pointerIsFunction(Special::Pointer pointer)
{
    ASSERT_UNUSED(pointer, pointer < Special::TableSize);
    return true;
}

inline bool pointerIsCell(Special::Pointer pointer)
{
    ASSERT_UNUSED(pointer, pointer < Special::TableSize);
    return true;
}

void* actualPointerFor(JSGlobalObject*, Special::Pointer);
void* actualPointerFor(CodeBlock*, Special::Pointer);

} // namespace JSC

==> webkit2gtk_2.26.1.orig.tar.xz: webkitgtk-2.26.1/Source/JavaScriptCore/bytecode/SpecialPointer.h <==
/*
 * Copyright (C) 2012-2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

namespace JSC {

class CodeBlock;
class JSGlobalObject;

namespace Special {
enum Pointer : unsigned {
    CallFunction,
    ApplyFunction,
    ObjectConstructor,
    ArrayConstructor,
    TableSize // Not a real special pointer. Use this to determine the number of pointers.
};
} // namespace Special

enum class LinkTimeConstant {
    ThrowTypeErrorFunction,
};
const unsigned LinkTimeConstantCount = 1;

inline bool pointerIsFunction(Special::Pointer pointer)
{
    ASSERT_UNUSED(pointer, pointer < Special::TableSize);
    return true;
}

inline bool pointerIsCell(Special::Pointer pointer)
{
    ASSERT_UNUSED(pointer, pointer < Special::TableSize);
    return true;
}

void* actualPointerFor(JSGlobalObject*, Special::Pointer);
void* actualPointerFor(CodeBlock*, Special::Pointer);

} // namespace JSC

namespace WTF {

class PrintStream;

void printInternal(PrintStream&, JSC::Special::Pointer);

} // namespace WTF
